<h2 align="center">BBA</h2>
BBA is An object oriented, synchronous api wrapper for BreadBotAPI.

# Important Links

- [get api key](https://api.breadbot.me/login)
- [support server](https://discord.gg/nbWfGT6PFR) 
- [Documentations](https://api.breadbot.me)
